# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import Required, TypedDict

__all__ = ["RegistryCreateParams"]


class RegistryCreateParams(TypedDict, total=False):
    name: Required[str]

    password: Required[str]

    url: Required[str]

    username: Required[str]
